pub fn apply_resource_update<T: SyncResource>(world: &mut World, bytes: &[u8])Expand description
Applies a resource snapshot only when the serialized value actually changed.
pub fn apply_resource_update<T: SyncResource>(world: &mut World, bytes: &[u8])Applies a resource snapshot only when the serialized value actually changed.